/*
 * exec.h
 *
 * SVN Info
 *    $Id: exec_save.h 19833 2007-07-13 22:02:25Z petdance $
 * Overview:
 *    Exec header file.
 * History:
 *      Initial version by Daniel Grunblatt on 2003.6.9
 * Notes:
 * References:
 */

#ifndef PARROT_EXEC_SAVE_H_GUARD
#define PARROT_EXEC_SAVE_H_GUARD

void Parrot_exec_save(PARROT_INTERP, Parrot_exec_objfile_t *obj, const char *file);

#endif /* PARROT_EXEC_SAVE_H_GUARD */


/*
 * Local variables:
 *   c-file-style: "parrot"
 * End:
 * vim: expandtab shiftwidth=4:
 */
